@@ -1,8 +1,10 @@
+import copy
 import shutil
 import warnings
 from collections import defaultdict
 from pathlib import Path
 from typing import Dict, List, Union
+
 from git import Repo
 
 from openpecha import blupdate, config
@@ -33,7 +35,7 @@ class OpenPecha:
         metadata: PechaMetadata = None,
         assets: Dict[str, List[Union[str, Path]]] = None,
         components: Dict[str, List[Layer]] = None,
-        pecha_id: str = None
+        pecha_id: str = None,
     ):
         self._pecha_id = pecha_id
         self.bases = bases if bases else {}
@@ -63,8 +65,10 @@ class OpenPecha:
 
     @property
     def about(self):
+        if not self.meta.source_metadata:
+            return ""
         source_metadata = []
-        descriptive_labels = ['title', 'author', 'id']
+        descriptive_labels = ["title", "author", "id"]
         for label, info in self.meta.source_metadata.items():
             if label in descriptive_labels:
                 if isinstance(info, list):
@@ -112,13 +116,18 @@ class OpenPecha:
             return self._components
         self._components = self._read_components()
         return self._components
-    
+
     @property
     def is_private(self):
         if self.meta.source_metadata:
-            if self.meta.source_metadata.get("geo_restriction", []) or self.meta.source_metadata.get("restrictedInChina", False):
+            if self.meta.source_metadata.get(
+                "geo_restriction", []
+            ) or self.meta.source_metadata.get("restrictedInChina", False):
                 return True
-            if self.meta.source_metadata.get("access", "") != "http://purl.bdrc.io/admindata/AccessOpen":
+            if (
+                self.meta.source_metadata.get("access", "")
+                != "http://purl.bdrc.io/admindata/AccessOpen"
+            ):
                 return True
         return False
 
@@ -127,7 +136,7 @@ class OpenPecha:
 
     def _set_base_metadata(self, base_name: str, metadata: Dict) -> None:
         metadata.update({"base_file": f"{base_name}.txt"})
-        if "bases" not in self.meta:
+        if not hasattr(self.meta, "bases"):
             self.meta.bases = {}
         self.meta.bases[base_name] = metadata
 
@@ -138,9 +147,15 @@ class OpenPecha:
         return self.bases[base_name]
 
     def get_base_metadata(self, base_name: str) -> str:
-        self.meta.bases.get(base_name)
+        return self.meta.bases.get(base_name)
 
-    def set_base(self, content: str, base_name: str = None, metadata: Dict = {}, update_layer_coordinates = True) -> str:
+    def set_base(
+        self,
+        content: str,
+        base_name: str = None,
+        metadata: Dict = {},
+        update_layer_coordinates=True,
+    ) -> str:
         """Create new base with `content` if `base_name` is not
         given otherwise overwrites it and return base_name.
         """
@@ -151,9 +166,9 @@ class OpenPecha:
                 blupdate.update_single_base(self, base_name, content)
             self.bases[base_name] = content
         else:
-            
+
             self.bases[base_name] = content
-            self._set_base_metadata(base_name, metadata)
+            self._set_base_metadata(base_name, copy.deepcopy(metadata))
         return base_name
 
     def get_layers(self, base_name: str) -> Layer:
@@ -166,7 +181,7 @@ class OpenPecha:
             if layer:
                 return layer
 
-        layer_dict = self.read_layers_file(base_name, layer_name.value)
+        layer_dict = self.read_layers_file(base_name, layer_name)
         if layer_dict:
             layer = Layer.parse_obj(layer_dict)
         else:
@@ -228,11 +243,9 @@ class OpenPechaFS(OpenPecha):
         path (str): path to .opf directory.
     """
 
-    def __init__(
-        self, path: str, pecha_id: str = None, **kwargs
-    ):
-        self._opf_path = Path(path)
-        super().__init__(pecha_id = pecha_id, **kwargs)
+    def __init__(self, path: str = None, pecha_id: str = None, **kwargs):
+        self._opf_path = Path(path) if path else None
+        super().__init__(pecha_id=pecha_id, **kwargs)
 
     @staticmethod
     def _mkdir(path: Path):
@@ -271,7 +284,7 @@ class OpenPechaFS(OpenPecha):
     def read_layers_file(
         self, base_name: str, layer_name: LayerEnum
     ) -> Union[Dict, None]:
-        layer_fn = self.layers_path / base_name / f"{layer_name}.yml"
+        layer_fn = self.layers_path / base_name / f"{layer_name.value}.yml"
         if layer_fn.is_file():
             return load_yaml(layer_fn)
 
@@ -300,7 +313,7 @@ class OpenPechaFS(OpenPecha):
         return res
 
     def save_meta(self):
-        OpenPechaFS._mkdir(self.base_path)  
+        OpenPechaFS._mkdir(self.base_path)
         dump_yaml(self.meta.dict(exclude_none=True), self.meta_fn)
 
     def save_single_base(self, base_name: str, content: str = None):
@@ -308,16 +321,19 @@ class OpenPechaFS(OpenPecha):
             content = self.bases[base_name]
         base_fn = OpenPechaFS._mkdir(self.base_path) / f"{base_name}.txt"
         if content:
-            base_fn.write_text(content, encoding='utf-8')
+            base_fn.write_text(content, encoding="utf-8")
         else:
-            base_fn.unlink()
+            if base_fn.exists():
+                base_fn.unlink()
 
     def save_base(self):
         for base_name, content in self.bases.items():
             self.save_single_base(base_name, content)
 
     def save_layer(self, base_name: str, layer_name: LayerEnum, layer: Layer):
-        layer_fn = OpenPechaFS._mkdir(self.layers_path / base_name) / f"{layer_name.value}.yml"
+        layer_fn = (
+            OpenPechaFS._mkdir(self.layers_path / base_name) / f"{layer_name.value}.yml"
+        )
         dump_yaml(layer.dict(exclude_none=True), layer_fn)
         return layer_fn
 
@@ -396,13 +412,12 @@ class OpenPechaGitRepo(OpenPechaFS):
         storage (Storage): storage for distant interaction.
     """
 
-
     def __init__(
         self, pecha_id: str = None, path: str = None, storage: Storage = None, **kwargs
     ):
         self._opf_path = OpenPechaGitRepo.get_opf_path(pecha_id, path)
         self.storage = storage
-        super().__init__(pecha_id = pecha_id, path = self._opf_path, **kwargs)
+        super().__init__(pecha_id=pecha_id, path=self._opf_path, **kwargs)
 
     @staticmethod
     def get_opf_path(pecha_id, path: str) -> Path:
@@ -434,7 +449,7 @@ class OpenPechaGitRepo(OpenPechaFS):
         self._opf_path = self.pecha_path / f"{self.pecha_id}.opf"
         return self._opf_path
 
-    def publish(self, asset_path:Path=None, asset_name:str=None):
+    def publish(self, asset_path: Path = None, asset_name: str = None):
         asset_paths = []
         if not self.storage:
             self.storage = GithubStorage()
@@ -442,7 +457,9 @@ class OpenPechaGitRepo(OpenPechaFS):
             local_repo = Repo(self.pecha_path)
             commit_and_push(repo=local_repo, message="Pecha update")
         else:
-            self.storage.add_dir(path=self.pecha_path, description=self.about, is_private=self.is_private)
+            self.storage.add_dir(
+                path=self.pecha_path, description=self.about, is_private=self.is_private
+            )
 
         # Publishing assets in release
         if asset_path:
@@ -450,7 +467,11 @@ class OpenPechaGitRepo(OpenPechaFS):
             shutil.make_archive(asset_path.parent / asset_name, "zip", asset_path)
             asset_paths.append(f"{asset_path.parent / asset_name}.zip")
             create_release(
-                repo_name, prerelease=False, asset_paths=asset_paths, org=self.storage.org_name, token=self.storage.token
+                repo_name,
+                prerelease=False,
+                asset_paths=asset_paths,
+                org=self.storage.org_name,
+                token=self.storage.token,
             )
             (asset_path.parent / f"{asset_name}.zip").unlink()
 
@@ -475,9 +496,14 @@ class OpenPechaBareGitRepo(OpenPecha):
     """
 
     def __init__(
-        self, pecha_id: str = None, path: str = None, revision: str = "HEAD", repo=None, **kwargs
+        self,
+        pecha_id: str = None,
+        path: str = None,
+        revision: str = "HEAD",
+        repo=None,
+        **kwargs,
     ):
-        super().__init__(pecha_id = pecha_id, **kwargs)
+        super().__init__(pecha_id=pecha_id, **kwargs)
         self.rev = revision
         if repo is not None:
             self.repo = repo
@@ -533,11 +559,12 @@ class OpenPechaBareGitRepo(OpenPecha):
     def read_layers_file(
         self, base_name: str, layer_name: LayerEnum
     ) -> Union[Dict, None]:
-        return self.read_file_content_yml("layers/" + base_name + "/" + layer_name + ".yml")
+        return self.read_file_content_yml(
+            "layers/" + base_name + "/" + layer_name + ".yml"
+        )
 
     def read_meta_file(self) -> Dict:
         return self.read_file_content_yml("meta.yml")
 
     def read_index_file(self) -> Dict:
         return self.read_file_content_yml("index.yml")
-
