@@ -8,6 +8,7 @@ import json
 import logging
 import datetime
 import statistics
+from zipfile import ZipFile
 from datetime import timezone
 from bs4 import BeautifulSoup
 
@@ -19,7 +20,7 @@ from openpecha.utils import load_yaml, dump_yaml, gzip_str
 from openpecha.buda.api import get_buda_scan_info, get_image_list, image_group_to_folder_name
 
 
-class HOCRBDRCFileProvider():
+class BDRCGBFileProvider():
     def __init__(self, bdrc_scan_id, buda_data, ocr_import_info, ocr_disk_path):
         self.ocr_import_info = ocr_import_info
         # disk path is the path to a directory that contains "info" and "output" subfolders
@@ -27,6 +28,8 @@ class HOCRBDRCFileProvider():
         self.bdrc_scan_id = bdrc_scan_id
         self.buda_data = buda_data
         self.images_info = {}
+        self.cur_zip = None
+        self.cur_image_group_id = None
     
 
     def get_image_list(self, image_group_id):
@@ -40,6 +43,7 @@ class HOCRBDRCFileProvider():
         # format should be a list of image_id (/ file names)
         return map(lambda ii: ii["filename"], buda_il)
     
+    
     def get_images_info(self, image_group_id):
         """load page_filename with image_filename mapping to images.info
 
@@ -65,6 +69,22 @@ class HOCRBDRCFileProvider():
             if img_id == image_id:
                 return filename
 
+    def get_image_group_data(self, image_group_id):
+        """unzip the html.zip of the image_group_id and return it
+
+        Args:
+            image_group_id (str): image_group_id of the volume
+
+        Returns:
+            self.cur_zip: unzip content of the html.zip
+        """
+        if image_group_id == self.cur_image_group_id and self.cur_zip is not None:
+            return self.cur_zip
+        vol_folder = image_group_to_folder_name(self.bdrc_scan_id, image_group_id)
+        zip_path = Path(f"{self.ocr_disk_path}") / "output" / vol_folder / "html.zip"
+        self.cur_zip = ZipFile(zip_path)
+        return self.cur_zip
+    
     def get_image_data(self, image_group_id, image_filename):
         """get hocr_filename using image_filename,
            use volume folder and hocr_filename to read the hocr_html file for the image_filename or the page
@@ -75,14 +95,15 @@ class HOCRBDRCFileProvider():
         Returns:
             hocr_html: html file of the image_filename
         """
-        vol_folder = image_group_to_folder_name(self.bdrc_scan_id, image_group_id)
-        hocr_filename = self.get_hocr_filename(image_filename)
-        image_hocr_path = Path(f"{self.ocr_disk_path}") / "output" / vol_folder / f"{hocr_filename}.html"
-        if os.path.isfile(image_hocr_path):
-            hocr_html = image_hocr_path.read_text(encoding='utf-8')
-            return hocr_html
-        else:
-            return
+        hocr_filename = self.get_hocr_filename(image_filename)+".html"
+        zf = self.get_image_group_data(image_group_id)
+        try:
+            for filename in zf.filelist:
+                if filename.filename.split("/")[-1] == hocr_filename:
+                    with zf.open(filename.filename) as hocr_file:
+                        return hocr_file.read()
+        except:
+            return 
 
 class HOCRIAFileProvider():
     def __init__(self, bdrc_scan_id, bdrc_image_list_path, buda_data, ocr_import_info, ocr_disk_path=None):
