@@ -1,8 +1,9 @@
 import re
 from pathlib import Path
+
 from openpecha.blupdate import *
-from openpecha.cli import download_pecha
-from openpecha.utils import load_yaml, dump_yaml
+from openpecha.utils import download_pecha, dump_yaml, load_yaml
+
 
 def get_meta(pecha_id, branch="main", pecha_path=None):
     """Return meta data of pecha
@@ -19,6 +20,7 @@ def get_meta(pecha_id, branch="main", pecha_path=None):
     meta = load_yaml(Path(f"{pecha_path}/{pecha_id}.opf/meta.yml"))
     return meta
 
+
 def get_pagination_layer(pecha_id, vol_meta, branch="main", pecha_path=None):
     """Return pagination layer of a volume from pecha opf of mentioned pecha id
 
@@ -30,12 +32,15 @@ def get_pagination_layer(pecha_id, vol_meta, branch="main", pecha_path=None):
     Returns:
         dict: pagination layer of the volume passed in parameter from mentioned pecha_id in parameter
     """
-    vol_id = re.sub(r'\..+', '', vol_meta['base_file'])
+    vol_id = re.sub(r"\..+", "", vol_meta["base_file"])
     if not pecha_path:
         pecha_path = download_pecha(pecha_id, branch=branch)
-    pagination_layer = load_yaml(Path(f'{pecha_path}/{pecha_id}.opf/layers/{vol_id}/Pagination.yml'))
+    pagination_layer = load_yaml(
+        Path(f"{pecha_path}/{pecha_id}.opf/layers/{vol_id}/Pagination.yml")
+    )
     return pagination_layer
 
+
 def get_vol_info(pecha_id, branch="main", pecha_path=None):
     """Return volumes information in pecha
     Args:
@@ -47,15 +52,16 @@ def get_vol_info(pecha_id, branch="main", pecha_path=None):
     """
     vols = []
     meta_data = get_meta(pecha_id, branch=branch, pecha_path=pecha_path)
-    for vol_uuid, vol_info in meta_data['source_metadata']['volumes'].items():
+    for vol_uuid, vol_info in meta_data["source_metadata"]["volumes"].items():
         cur_vol = {
-            'id': vol_uuid,
-            'title': vol_info['title'],
-            'image_group_id': vol_info['image_group_id']
+            "id": vol_uuid,
+            "title": vol_info["title"],
+            "image_group_id": vol_info["image_group_id"],
         }
         vols.append(cur_vol)
     return vols
 
+
 def get_pages_info(pecha_id, vol_id, branch="main", pecha_path=None):
     """Return page annotation's uuids in mentioned volume number
 
@@ -67,14 +73,17 @@ def get_pages_info(pecha_id, vol_id, branch="main", pecha_path=None):
     Returns:
         list: page annotation's uuids in mentioned volume number in sorted order
     """
-    
+
     pages = []
     pecha_meta = get_meta(pecha_id, branch=branch, pecha_path=pecha_path)
-    vol_meta = pecha_meta['source_metadata']['volumes'][vol_id]
-    pagination_layer = get_pagination_layer(pecha_id, vol_meta, branch=branch, pecha_path=pecha_path)
-    pages = [ann_uuid for ann_uuid, ann in pagination_layer['annotations'].items()]
+    vol_meta = pecha_meta["source_metadata"]["volumes"][vol_id]
+    pagination_layer = get_pagination_layer(
+        pecha_id, vol_meta, branch=branch, pecha_path=pecha_path
+    )
+    pages = [ann_uuid for ann_uuid, ann in pagination_layer["annotations"].items()]
     return pages
 
+
 def get_base_text(pecha_id, vol_meta, branch="main", pecha_path=None):
     """Return base text of the mentioned volume number
 
@@ -86,13 +95,16 @@ def get_base_text(pecha_id, vol_meta, branch="main", pecha_path=None):
     Returns:
         str: base text of volume
     """
-    base_text = ''
-    base_fn = vol_meta['base_file']
+    base_text = ""
+    base_fn = vol_meta["base_file"]
     if not pecha_path:
         pecha_path = download_pecha(pecha_id, branch=branch)
-    base_text = Path(f'{pecha_path}/{pecha_id}.opf/base/{base_fn}').read_text(encoding='utf-8')
+    base_text = Path(f"{pecha_path}/{pecha_id}.opf/base/{base_fn}").read_text(
+        encoding="utf-8"
+    )
     return base_text
 
+
 def get_page_content(page_ann, base_text):
     """Return page content from base text
 
@@ -103,12 +115,13 @@ def get_page_content(page_ann, base_text):
     Returns:
         str: page content
     """
-    page_span = page_ann['span']
-    page_start_idx = page_span['start']
-    page_end_idx = page_span['end']
-    page_content = base_text[page_start_idx:page_end_idx+1]
+    page_span = page_ann["span"]
+    page_start_idx = page_span["start"]
+    page_end_idx = page_span["end"]
+    page_content = base_text[page_start_idx : page_end_idx + 1]
     return page_content
 
+
 def get_page_image_url(page_ann, vol_meta):
     """Return image url of the page
 
@@ -119,12 +132,13 @@ def get_page_image_url(page_ann, vol_meta):
     Returns:
         str: image url of page
     """
-    cur_image_grp_id = ''
-    cur_image_grp_id = vol_meta['image_group_id']
-    image_ref = page_ann['reference']
+    cur_image_grp_id = ""
+    cur_image_grp_id = vol_meta["image_group_id"]
+    image_ref = page_ann["reference"]
     image_url = f"https://iiif.bdrc.io/bdr:{cur_image_grp_id}::{image_ref}/full/max/0/default.jpg"
     return image_url
 
+
 def get_page(pecha_id, vol_id, page_id, branch="main", pecha_path=None):
     """Return page detail of mentioned page id
 
@@ -137,20 +151,19 @@ def get_page(pecha_id, vol_id, page_id, branch="main", pecha_path=None):
     Returns:
         dict: page content and image url of page will be return
     """
-    page_info = {
-        'content': None,
-        'image_url': None,
-    }
+    page_info = {"content": None, "image_url": None}
     pecha_meta = get_meta(pecha_id, branch=branch, pecha_path=pecha_path)
-    vol_meta = pecha_meta['source_metadata']['volumes'][vol_id]
-    pagination_layer = get_pagination_layer(pecha_id, vol_meta, branch=branch, pecha_path=pecha_path)
+    vol_meta = pecha_meta["source_metadata"]["volumes"][vol_id]
+    pagination_layer = get_pagination_layer(
+        pecha_id, vol_meta, branch=branch, pecha_path=pecha_path
+    )
     base_text = get_base_text(pecha_id, vol_meta, branch=branch, pecha_path=pecha_path)
-    cur_page_ann = pagination_layer['annotations'][page_id]
-    page_info['content'] = get_page_content(cur_page_ann, base_text)
-    page_info['image_url'] = get_page_image_url(cur_page_ann, vol_meta)
+    cur_page_ann = pagination_layer["annotations"][page_id]
+    page_info["content"] = get_page_content(cur_page_ann, base_text)
+    page_info["image_url"] = get_page_image_url(cur_page_ann, vol_meta)
     return page_info
 
-    
+
 def get_new_vol(old_vol, old_page, new_page_content):
     """Return new volume content by replacing old page with new page in old volume
 
@@ -167,6 +180,7 @@ def get_new_vol(old_vol, old_page, new_page_content):
     new_vol = old_vol.replace(old_page, new_page)
     return new_vol
 
+
 def update_layer(pecha_path, pecha_id, vol_id, old_layers, updater):
     """Save updated layer using updater object
 
@@ -179,9 +193,12 @@ def update_layer(pecha_path, pecha_id, vol_id, old_layers, updater):
     """
     for layer_name, old_layer in old_layers.items():
         update_ann_layer(old_layer, updater)
-        new_layer_path = Path(f"{pecha_path}/{pecha_id}.opf/layers/{vol_id}/{layer_name}.yml")
+        new_layer_path = Path(
+            f"{pecha_path}/{pecha_id}.opf/layers/{vol_id}/{layer_name}.yml"
+        )
         dump_yaml(old_layer, new_layer_path)
-        print(f'INFO: {vol_id} {layer_name} has been updated...')
+        print(f"INFO: {vol_id} {layer_name} has been updated...")
+
 
 def get_old_layers(pecha_path, pecha_id, vol_id):
     """Return old layer of the mentioned volume id
@@ -201,7 +218,8 @@ def get_old_layers(pecha_path, pecha_id, vol_id):
         layer_content = load_yaml(layer_path)
         old_layers[layer_name] = layer_content
     return old_layers
-       
+
+
 def update_old_layers(pecha_path, pecha_id, old_vol, new_vol, vol_meta):
     """Update old layer while change recorded in base text
 
@@ -212,11 +230,12 @@ def update_old_layers(pecha_path, pecha_id, old_vol, new_vol, vol_meta):
         new_vol (str): new base text
         vol_meta (dict): volume meta data
     """
-    vol_id = re.sub(r'\..+', '', vol_meta['base_file'])
+    vol_id = re.sub(r"\..+", "", vol_meta["base_file"])
     updater = Blupdate(old_vol, new_vol)
     old_layers = get_old_layers(pecha_path, pecha_id, vol_id)
     update_layer(pecha_path, pecha_id, vol_id, old_layers, updater)
 
+
 def update_base(pecha_path, pecha_id, vol_meta, new_vol):
     """Update old base text by overwriting the new base text
 
@@ -226,25 +245,47 @@ def update_base(pecha_path, pecha_id, vol_meta, new_vol):
         vol_meta (dict): volume meta data
         new_vol (str): updated base text
     """
-    base_fn = vol_meta['base_file']
-    Path(f"{pecha_path}/{pecha_id}.opf/base/{base_fn}").write_text(new_vol, encoding='utf-8')
-    print(f'INFO: {base_fn} base updated..')
+    base_fn = vol_meta["base_file"]
+    Path(f"{pecha_path}/{pecha_id}.opf/base/{base_fn}").write_text(
+        new_vol, encoding="utf-8"
+    )
+    print(f"INFO: {base_fn} base updated..")
+
 
 def update_sub_text(old_pecha_idx, text_info, vol_num, vol_offset, page_start):
+    """Update span of sub text acording to offset
+
+    Args:
+        old_pecha_idx (dict): old pecha index
+        text_info (list): contains text uuid and text annotation details
+        vol_num (int): volume number
+        vol_offset (int): offset between new and old base text
+        page_start (int): starting span of the page which you want to save
+
+    Returns:
+        dict: old pecha with updated sub text span
+    """
+    new_pecha_idx = old_pecha_idx
     check_next_sub_text = True
     text_uuid = text_info[0]
     text_ann = text_info[1]
-    for sub_text_uuid, sub_text_ann in text_ann['parts'].items():
-        sub_text_span = sub_text_ann['span']
+    for sub_text_uuid, sub_text_ann in text_ann["parts"].items():
+        sub_text_span = sub_text_ann["span"]
         for vol_walker, vol_span in enumerate(sub_text_span):
-            if vol_span['vol'] == vol_num and vol_span['end'] >= page_start:
-                old_pecha_idx["annotations"][text_uuid]['parts'][sub_text_uuid]['span'][vol_walker]['end'] += vol_offset
-            elif vol_span['vol'] > vol_num:
+            if vol_span["vol"] == vol_num and vol_span["start"] > page_start:
+                new_pecha_idx["annotations"][text_uuid]["parts"][sub_text_uuid]["span"][
+                    vol_walker
+                ]["start"] += vol_offset
+            if vol_span["vol"] == vol_num and vol_span["end"] >= page_start:
+                new_pecha_idx["annotations"][text_uuid]["parts"][sub_text_uuid]["span"][
+                    vol_walker
+                ]["end"] += vol_offset
+            elif vol_span["vol"] > vol_num:
                 check_next_sub_text = False
                 break
         if not check_next_sub_text:
             break
-    return old_pecha_idx
+    return new_pecha_idx
 
 
 def update_index(vol_offset, vol_meta, page_start, old_pecha_idx):
@@ -259,23 +300,33 @@ def update_index(vol_offset, vol_meta, page_start, old_pecha_idx):
     Returns:
         dict: new index with new span using offset to adjust
     """
-    vol_num = int(re.search(r'\d+',vol_meta['base_file'])[0])
+    new_pecha_idx = old_pecha_idx
+    vol_num = int(re.search(r"\d+", vol_meta["base_file"])[0])
     check_next_text = True
     if vol_offset != 0:
-        for text_uuid, text_ann in old_pecha_idx["annotations"].items():
-            if text_ann['parts']:
+        for text_uuid, text_ann in new_pecha_idx["annotations"].items():
+            if text_ann["parts"]:
                 text_info = [text_uuid, text_ann]
-                old_pecha_idx = update_sub_text(old_pecha_idx, text_info, vol_num, vol_offset, page_start)
-            text_span = text_ann['span']
+                new_pecha_idx = update_sub_text(
+                    new_pecha_idx, text_info, vol_num, vol_offset, page_start
+                )
+            text_span = text_ann["span"]
             for vol_walker, vol_span in enumerate(text_span):
-                if vol_span['vol'] == vol_num and vol_span['end'] >= page_start:
-                    old_pecha_idx["annotations"][text_uuid]['span'][vol_walker]['end'] += vol_offset
-                elif vol_span['vol'] > vol_num:
+                if vol_span["vol"] == vol_num and vol_span["start"] > page_start:
+                    new_pecha_idx["annotations"][text_uuid]["span"][vol_walker][
+                        "start"
+                    ] += vol_offset
+                if vol_span["vol"] == vol_num and vol_span["end"] >= page_start:
+                    new_pecha_idx["annotations"][text_uuid]["span"][vol_walker][
+                        "end"
+                    ] += vol_offset
+                elif vol_span["vol"] > vol_num:
                     check_next_text = False
                     break
             if not check_next_text:
                 break
-    return old_pecha_idx
+    return new_pecha_idx
+
 
 def save_page(pecha_id, vol_id, page_id, page_content, branch="main", pecha_path=None):
     """Save new page in opf
@@ -291,20 +342,24 @@ def save_page(pecha_id, vol_id, page_id, page_content, branch="main", pecha_path
         path: pecha path of updated opf
     """
     pecha_meta = get_meta(pecha_id, branch=branch, pecha_path=pecha_path)
-    vol_meta = pecha_meta['source_metadata']['volumes'][vol_id]
+    vol_meta = pecha_meta["source_metadata"]["volumes"][vol_id]
     if not pecha_path:
         pecha_path = download_pecha(pecha_id, branch=branch)
-    old_pecha_idx = load_yaml(Path(f'{pecha_path}/{pecha_id}.opf/index.yml'))
-    pagination_layer = get_pagination_layer(pecha_id, vol_meta, branch=branch, pecha_path=pecha_path)
+    old_pecha_idx = load_yaml(Path(f"{pecha_path}/{pecha_id}.opf/index.yml"))
+    pagination_layer = get_pagination_layer(
+        pecha_id, vol_meta, branch=branch, pecha_path=pecha_path
+    )
     old_vol = get_base_text(pecha_id, vol_meta, branch=branch, pecha_path=pecha_path)
-    cur_page_ann = pagination_layer['annotations'][page_id]
+    cur_page_ann = pagination_layer["annotations"][page_id]
     old_page = get_page_content(cur_page_ann, old_vol)
     new_vol = get_new_vol(old_vol, old_page, new_page_content=page_content)
     vol_offset = len(new_vol) - len(old_vol)
-    new_pecha_idx = update_index(vol_offset, vol_meta, cur_page_ann['span']['start'], old_pecha_idx)
+    new_pecha_idx = update_index(
+        vol_offset, vol_meta, cur_page_ann["span"]["start"], old_pecha_idx
+    )
     update_old_layers(pecha_path, pecha_id, old_vol, new_vol, vol_meta)
     update_base(pecha_path, pecha_id, vol_meta, new_vol)
-    new_pecha_idx_path = dump_yaml(new_pecha_idx, Path(f"{pecha_path}/{pecha_id}.opf/index.yml"))
+    new_pecha_idx_path = dump_yaml(
+        new_pecha_idx, Path(f"{pecha_path}/{pecha_id}.opf/index.yml")
+    )
     return pecha_path
-    
-
